summaryrefslogtreecommitdiff
path: root/src/livery.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/livery.h')
-rw-r--r--src/livery.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/livery.h b/src/livery.h
index a5f6674c4..719aeb798 100644
--- a/src/livery.h
+++ b/src/livery.h
@@ -67,10 +67,10 @@ struct Livery {
};
/**
* Reset the livery schemes to the player's primary colour.
* This is used on loading games without livery information and on new player start up.
* @param p Player to reset.
*/
-void ResetPlayerLivery(Player *p);
+void ResetCompanyLivery(Company *c);
#endif /* LIVERY_H */
@@ -67,10 +67,10 @@ struct Livery {
};
/**
- * Reset the livery schemes to the player's primary colour.
- * This is used on loading games without livery information and on new player start up.
- * @param p Player to reset.
+ * Reset the livery schemes to the company's primary colour.
+ * This is used on loading games without livery information and on new company start up.
+ * @param c Company to reset.
*/